@@ -13,6 +13,7 @@ class API(object):
         self.domain_ws = 'ws://47.90.247.3:34338/api/PriceStream/'
         self.refresh_token(username,password)
         self.price = None
+        self.bars = {}
         
 
     def refresh_token(self,username,password):
@@ -69,8 +70,9 @@ class API(object):
         response = requests.get(link, headers = {'TOKEN': f'{self.token}'})
         return response.json()
     
-    def initialize_price_stream(self, symbol):
+    def initialize_price_stream(self, symbol, timeframe):
         self.price = websocket.create_connection(self.domain_ws + symbol,header={'TOKEN': self.token})
+        self.bars[timeframe] = self.bar_chart(symbol, timeframe)[-1]['Ctm']
 
     def current_price(self):
         return json.loads(self.price.recv())
@@ -91,3 +93,10 @@ class API(object):
             result[key]['High'] = round((result[key]['High'] * (10**-digit)) + result[key]['Open'], digit)
             result[key]['Low'] = round((result[key]['Low'] * (10**-digit)) + result[key]['Open'], digit)
         return result
+
+    def check_new_bar(self,symbol,timeframe):
+        if self.bar_chart(symbol,timeframe)[-1]['Ctm'] == self.bars[timeframe]:
+            return False
+        else:
+            self.bars[timeframe] = self.bar_chart(symbol,timeframe)[-1]['Ctm'] 
+            return True
\ No newline at end of file
